/** @LICENSE
 * @hi-ui/highlighter
 * https://github.com/XiaoMi/hiui/tree/master/packages/ui/highlighter#readme
 *
 * Copyright (c) HiUI <mi-hiui@xiaomi.com>.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { __rest } from 'tslib';
import React, { forwardRef, useRef } from 'react';
import { getPrefixCls, cx } from '@hi-ui/classname';
import { __DEV__ } from '@hi-ui/env';
var HIGHLIGHTER_PREFIX = getPrefixCls('highlighter');
/**
 * 高亮文本内容
 */
var Highlighter = /*#__PURE__*/forwardRef(function (_a, ref) {
  var _a$prefixCls = _a.prefixCls,
    prefixCls = _a$prefixCls === void 0 ? HIGHLIGHTER_PREFIX : _a$prefixCls,
    className = _a.className,
    keyword = _a.keyword,
    _a$children = _a.children,
    children = _a$children === void 0 ? null : _a$children,
    rest = __rest(_a, ["prefixCls", "className", "keyword", "children"]);
  var startIndex = useRef(0);
  if (!keyword) return children;
  if (typeof children !== 'string') return children;
  // 支持多个匹配高亮
  var parts = children.split(keyword);
  var matches = children.match(keyword);
  // 未匹配到
  if (parts.length < 2) return children;
  var lastPart = parts.pop();
  var cls = cx(prefixCls, className);
  // TODO: 容器宽度有限但文本过长时，自动适配关键词到可见区域
  return /*#__PURE__*/React.createElement("span", Object.assign({
    ref: ref,
    className: cls
  }, rest), parts.reduce(function (acc, part, index) {
    var matched = typeof keyword === 'string' ? keyword : matches[index];
    startIndex.current += part.length;
    acc.push(part);
    acc.push( /*#__PURE__*/React.createElement("span", {
      key: index,
      className: prefixCls + "--matched"
    }, children.substring(startIndex.current, startIndex.current + matched.length)));
    startIndex.current += matched.length;
    return acc;
  }, []), lastPart);
});
if (__DEV__) {
  Highlighter.displayName = 'Highlighter';
}
export { Highlighter };
